/*
 * Copyright (C) 2018 Inteno Broadband Technology AB. All rights reserved.
 *
 * Authors: Hrvoje Varga    <hrvoje.varga@sartura.hr>
 *          Matija Amidzic  <matija.amidzic@sartura.hr>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 */

#include <string.h>

#include "control.h"
#include "uci_parser.h"
#include "monitor.h"
#include "debug.h"

int control_init(char *ubus_socket_path, char *uci_config_path)
{
    int error = 0;
    struct list_head monitors = LIST_HEAD_INIT(monitors);
    error = uci_parser_parse(uci_config_path, &monitors);
    if (error != 0) {
        _error("failed to parse uci configuration");
        goto free;
    }

    monitor_start(ubus_socket_path, &monitors);

free:
    uci_parser_free_resources(&monitors);

    return error;
}

void control_close()
{
    monitor_stop();
}
