/*
 * Copyright (C) 2018 Inteno Broadband Technology AB. All rights reserved.
 *
 * Authors: Hrvoje Varga    <hrvoje.varga@sartura.hr>
 *          Matija Amidzic  <matija.amidzic@sartura.hr>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 */

#ifndef __DEBUG_H__
#define __DEBUG_H__

#include <stdio.h>
#include <stdlib.h>
#include <syslog.h>
#include <string.h>
#include <time.h>

#define __FILENAME__ (strrchr(__FILE__, '/') ? strrchr(__FILE__, '/') + 1 : __FILE__)

#ifdef DEBUG1
#define _debug(fmt, ...)                                                                                                                             \
    do {                                                                                                                                             \
        fprintf(stderr, "[DEBUG1] [%u] %s (%s, %d): " fmt "\n", (unsigned) time(NULL), __FILENAME__, __FUNCTION__, __LINE__, ##__VA_ARGS__);         \
    } while (0)
#else
#define _debug(fmt, ...)                                                                                                                             \
    do {                                                                                                                                             \
    } while (0)
#endif

#ifdef DEBUG2
#define __debug(fmt, ...)                                                                                                                            \
    do {                                                                                                                                             \
        fprintf(stderr, "[DEBUG2] [%d] %s (%s, %d): " fmt "\n", (unsigned) time(NULL), __FILENAME__, __FUNCTION__, __LINE__, ##__VA_ARGS__);         \
    } while (0)
#else
#define __debug(fmt, ...)                                                                                                                            \
    do {                                                                                                                                             \
    } while (0)
#endif

#ifdef DEBUG3
#define ___debug(fmt, ...)                                                                                                                           \
    do {                                                                                                                                             \
        fprintf(stderr, "[DEBUG3] [%d] %s: %s (%d): " fmt "\n", (unsigned) time(NULL), __FILENAME__, __FUNCTION__, __LINE__, ##__VA_ARGS__);         \
    } while (0)
#else
#define ___debug(fmt, ...)                                                                                                                           \
    do {                                                                                                                                             \
    } while (0)
#endif

#ifdef LOG
#define _log(fmt, ...)                                                                                                                               \
    do {                                                                                                                                             \
        fprintf(stderr, "[LOG] %s (%s, %d): " fmt "\n", __FILENAME__, __FUNCTION__, __LINE__, ##__VA_ARGS__);                                        \
    } while (0)
#else
#define _log(fmt, ...)                                                                                                                               \
    do {                                                                                                                                             \
    } while (0)
#endif

#ifdef ERROR
#define _error(fmt, ...)                                                                                                                             \
    do {                                                                                                                                             \
        fprintf(stderr, "[ERROR] %s (%s, %d): " fmt "\n", __FILENAME__, __FUNCTION__, __LINE__, ##__VA_ARGS__);                                      \
    } while (0)
#else
#define _error(fmt, ...)                                                                                                                             \
    do {                                                                                                                                             \
    } while (0)
#endif

#ifdef ERROR_MEMORY
#define _error_memory(fmt, ...)                                                                                                                      \
    do {                                                                                                                                             \
        fprintf(stderr, "[EMEMORY] %s %s (%d): no enough memory" fmt "\n", __FILENAME__, __FUNCTION__, __LINE__, ##__VA_ARGS__);                     \
    } while (0)
#else
#define _error_memory(fmt, ...)                                                                                                                      \
    do {                                                                                                                                             \
    } while (0)
#endif

#ifdef SYSLOG_ERR
#define _syslog_err(fmt, ...)                                                                                                                        \
    do {                                                                                                                                             \
        syslog(LOG_ERR, "%s: " fmt, __FUNCTION__, ##__VA_ARGS__);                                                                                    \
    } while (0)
#else
#define _syslog_err(fmt, ...)                                                                                                                        \
    do {                                                                                                                                             \
    } while (0)
#endif

#ifdef SYSLOG_INFO
#define _syslog_info(fmt, ...)                                                                                                                       \
    do {                                                                                                                                             \
        syslog(LOG_INFO, "%s: " fmt, __FUNCTION__, ##__VA_ARGS__);                                                                                   \
    } while (0)
#else
#define _syslog_info(fmt, ...)                                                                                                                       \
    do {                                                                                                                                             \
    } while (0)
#endif

#ifdef SYSLOG_WARNING
#define _syslog_warning(fmt, ...)                                                                                                                    \
    do {                                                                                                                                             \
        syslog(LOG_WARNING, "%s: " fmt, __FUNCTION__, ##__VA_ARGS__);                                                                                \
    } while (0)
#else
#define _syslog_warning(fmt, ...)                                                                                                                    \
    do {                                                                                                                                             \
    } while (0)
#endif

#endif /* __DEBUG_H__ */
