/*
 * Copyright (C) 2018 Inteno Broadband Technology AB. All rights reserved.
 *
 * Authors: Hrvoje Varga    <hrvoje.varga@sartura.hr>
 *          Matija Amidzic  <matija.amidzic@sartura.hr>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 */

#include <stdlib.h>
#include <signal.h>
#include <unistd.h>
#include <stdio.h>

#include "control.h"

#define DEFAULT_UBUS_PATH "/var/run/ubus.sock"
#define DEFAULT_UCI_CONFIG_PATH "/etc/config/imonitor"

static char *ubus_socket_path = (char *) DEFAULT_UBUS_PATH;
static char *uci_config_path = (char *) DEFAULT_UCI_CONFIG_PATH;

static void show_usage(char *application_name)
{
    fprintf(stdout,
            "\nUsage: %s: <options>\n"
            "Options:\n"
            "  -s <socket> path to ubus socket [" DEFAULT_UBUS_PATH "]\n"
            "  -c <uci_config_path> uci config file containing monitoring configuration [" DEFAULT_UCI_CONFIG_PATH "]\n"
            "  -h help\n\n",
            application_name);
}

static void parse_command_line_args(int argc, char *argv[])
{
    int opt;
    while ((opt = getopt(argc, argv, "s:c:h")) != -1) {
        switch (opt) {
            case 's':
                ubus_socket_path = optarg;
                break;
            case 'c':
                uci_config_path = optarg;
                break;
            case 'h':
                show_usage(argv[0]);
                exit(EXIT_SUCCESS);
            default:
                show_usage(argv[0]);
                exit(EXIT_FAILURE);
                break;
        }
    }
}

int main(int argc, char *argv[])
{
    parse_command_line_args(argc, argv);
    control_init(ubus_socket_path, uci_config_path);
    control_close();
    return 0;
}
