/*
 * Copyright (C) 2018 Inteno Broadband Technology AB. All rights reserved.
 *
 * Authors: Hrvoje Varga    <hrvoje.varga@sartura.hr>
 *          Matija Amidzic  <matija.amidzic@sartura.hr>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 */

#ifndef __UCI_PARSER_H__

#include <libubox/list.h>

typedef enum {
    PARSE_SUCCESS = 0,
    PARSE_FAILED_INTERNAL_ERROR,
    PARSE_FAILED_MISSING_FILE,
    PARSE_FAILED_UCI_ERROR,
    PARSE_FAILED_MISSING_OPTION,
    PARSE_FAILED_INVALID_VALUE,
    PARSE_FAILED_INVALID_COMBINATION,
} parse_status_e;

/**
 * uci_parser_parse: Parse the imonitor uci configuration file.
 * @monitors: Empty linked list containing monitor_t nodes.
 *
 * If parsing is successful, linked list will be populated with monitor_t nodes.
 * Otherwise, an error will be returned and the linked list will be empty.
 *
 * Caller is responsible for freeing the allocated memory behind list.
 * Use uci_parser_free_resources() to free memory.
 */
parse_status_e uci_parser_parse(char *uci_config_path, struct list_head *monitors);

/**
 * uci_parser_free_resources: Free memory used by linked list.
 * @monitors: Linked list containing monitor_t nodes.
 */
void uci_parser_free_resources(struct list_head *monitors);

#define __UCI_PARSER_H__
#endif /* __UCI_PARSER_H */
